==> kmysqladmin-0.6.2.tar.gz: kmysqladmin-0.6.2/kmysqladmin/granttable.h <==
//-*-Mode: C++;-*-
/*
 * $Id: granttable.h,v 2.12 2003/02/04 00:08:53 ral Exp $
 */

#ifndef CGrantTable_included
#define CGrantTable_included

#include "granttabledata.h"
#include "PatternPair.h"
#include <qlist.h>
#include "kmysqladmin/helpers/stringlist.h"
#include "kmysqladmin/helpers/smart_pointer.h"

class CMySql;
class QListView;

class QString;

class CGrantTable : public CGrantTableData
{
    Q_OBJECT

public:
    CGrantTable(smart_pointer<CMySql>& _sql_server,QWidget* parent = NULL,const char* name = NULL);
    virtual ~CGrantTable();
    virtual void show();

protected slots:
    void hosthilighted(QListViewItem*);
    void userhilighted(QListViewItem*);
    void dbhilighted(QListViewItem*);
    void hostselected(QListViewItem*);
    void userselected(QListViewItem*);
    void dbselected(QListViewItem*);
    void ModifyUser();
    void ModifyHost();
    void ModifyDb();
    void AddHost();
    void AddUser();
    void AddDb();
    void Refresh();
    void DeleteUser();
    void DeleteHost();
    void DeleteDb();
    void FontChanged();

protected:
    smart_pointer<CMySql> sql_server;
    void ReadHostTable();
    void ReadUserTable(QString&Host);
    void ReadDBTable(QString&Host,QString&User);
    void DisableButtons();
    void append_Sel(stringlist*List);
    void append_Add(PatternList*List);
    void pass_error();
    void user_error();
    int Ask_delete();
    void Error();
    void UpdateGrants(int count);
    PatternList*break_dbstring();
    PatternList*break_userstring();
    PatternList*break_hoststring();

    static const char*Se_Str;
    static const char*In_Str;
    static const char*Up_Str;
    static const char*De_Str;
    static const char*Cr_Str;
    static const char*Dr_Str;
    static const char*Re_Str;
    static const char*Sh_Str;
    static const char*Pr_Str;
    static const char*Fi_Str;
    static const char*No;
    
    static const char*DB_Name;
    static const char*Host_Table;
    static const char*User_Table;
    static const char*DB_Table;
    static const char*Pass_Entry;
    static const char*Host_Title;
    
    QString User_Title;
    QString DB_Title;
    QString P_Title;
    QString P2_Title;
};
#endif // CGrantTable_included

==> kmysqladmin-0.32.tar.gz: kmysqladmin-0.32/kmysqladmin/granttable.h <==
//-*-Mode: C++;-*-
/*
 * $Id: granttable.h,v 2.4 1999/07/31 19:52:38 ral Exp $
 */

#ifndef CGrantTable_included
#define CGrantTable_included

#include "granttabledata.h"
#include "PatternPair.h"
#include <qlist.h>
#include "stringlist.h"

class CGrantTable : public CGrantTableData
{
    Q_OBJECT

public:
    CGrantTable(QWidget* parent = NULL,const char* name = NULL);
    virtual ~CGrantTable();
    virtual void show();

protected slots:
    void hosthilighted(int);
    void userhilighted(int);
    void dbhighlighted(int);
    void hostselected(int);
    void userselected(int);
    void dbselected(int);
    void ModifyUser();
    void ModifyHost();
    void ModifyDb();
    void AddHost();
    void AddUser();
    void AddDb();
    void Refresh();
    void DeleteUser();
    void DeleteHost();
    void DeleteDb();

private:
    void ReadHostTable();
    void ReadUserTable(const char*Host);
    void ReadDBTable(const char*Host,const char*User);
    void DisableButtons();
    void append_Sel(stringlist*List);
    void append_Add(PatternList*List);
    void pass_error();
    void user_error();
    int Ask_delete();
    void Error();
    PatternList*break_dbstring();
    PatternList*break_userstring();
    PatternList*break_hoststring();

    static const char*Se_Str;
    static const char*In_Str;
    static const char*Up_Str;
    static const char*De_Str;
    static const char*Cr_Str;
    static const char*Dr_Str;
    static const char*Re_Str;
    static const char*Sh_Str;
    static const char*Pr_Str;
    static const char*Fi_Str;
    static const char*No;
    
    static const char*DB_Name;
    static const char*Host_Table;
    static const char*User_Table;
    static const char*DB_Table;
    static const char*Pass_Entry;
    static const char*Host_Title;
    
    const char* User_Title;
    const char* DB_Title;
    const char* P_Title;
    const char* P2_Title;
};
#endif // CGrantTable_included
